==> haskell-hinotify-0.4.2-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-G9l2ZK1hQQW7VoBpQjw1Mx
key:                  hinotify-0.4.2-G9l2ZK1hQQW7VoBpQjw1Mx
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  eb032bda7dcd738a6c7c1a156863f5b4
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-G9l2ZK1hQQW7VoBpQjw1Mx
includes:             sys/inotify.h
depends:
    async-2.2.5-1XszS28nMj91eBjCxIzBEt base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hinotify-0.4.2-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hinotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-Fu88eBRzBBeLiROG6DHXuc
key:                  hinotify-0.4.2-Fu88eBRzBBeLiROG6DHXuc
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  be1542fbe7cc84477d1af18a27f390b1
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-Fu88eBRzBBeLiROG6DHXuc
includes:             sys/inotify.h
depends:
    async-2.2.5-BbDohv985MkKG2Ydm62Fmc base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
